package de.groygroy.java7;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import javax.swing.JComponent;
import javax.swing.JLayer;
import javax.swing.JTextField;
import javax.swing.plaf.LayerUI;

/**
 * Diese Klasse zeigt den gegebenen Text in leeren JTextFields an.
 * 
 * 
 * @author Carsten
 * @see Swing7
 */
class EingabeLayer extends LayerUI<JTextField> {

    private final String anzeige;

    /**
     * Standard Konstruktor
     * @param anzeige  der anzuzeigende Text
     */
    public EingabeLayer(String anzeige) {
        this.anzeige = anzeige;
    }

    @Override
    public void paint(Graphics g, JComponent c) {
        // JTextField unverändert malen
        super.paint(g, c);

        // JTextField bekommen
        JLayer<JTextField> layer = (JLayer<JTextField>) c;
        JTextField text = layer.getView();

        if (!(text.hasFocus())
                && text.getText().trim().length() == 0) {

            // Ab hier zusätzliche Maling 
            // über das Standard-Widget
            Graphics2D g2d = (Graphics2D)g;

            RenderingHints renderHints =
                    new RenderingHints(RenderingHints.KEY_ANTIALIASING,
                    RenderingHints.VALUE_ANTIALIAS_ON);
            renderHints.put(RenderingHints.KEY_RENDERING,
                    RenderingHints.VALUE_RENDER_QUALITY);
            g2d.setRenderingHints( renderHints);

            g2d.setColor(Color.DARK_GRAY);

            Rectangle bbox = text.getBounds();
            
            // Linie 
            g2d.drawLine(bbox.x, bbox.y, bbox.x + bbox.width, bbox.y + bbox.height);
            
            
            g2d.drawLine(bbox.x, bbox.y, bbox.x + bbox.width, bbox.y + bbox.height);

            // Text
            g2d.drawString(anzeige, bbox.x + 10, bbox.height - 10);
            
            
        }

    }
}
